@@ -15,11 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.h,v 1.1 2004/02/22 18:54:33 adamh Exp $
+ *  $Id: ErrorViewerURICheckerObserver.h,v 1.3 2004/04/19 04:00:43 adamh Exp $
  */
 
+#include "link-checker.h"
+
+#include <nsIDOMNode.h>
 #include <nsIRequestObserver.h>
-#include <glib-object.h>
 
 /* Header file */
 class ErrorViewerURICheckerObserver : public nsIRequestObserver
@@ -32,7 +34,12 @@ public:
   virtual ~ErrorViewerURICheckerObserver();
   /* additional members */
 
-  GObject *mChecker;
+  nsresult Init (LinkChecker *aChecker, const char *aFilename);
+  nsresult AddNode (nsIDOMNode *node);
+  nsresult DoneAdding (void);
+
+private:
+  LinkChecker *mChecker;
   char *mFilename;
   PRUint32 mNumLinksChecked;
   PRUint32 mNumLinksInvalid;
